# Medcom BLE communication library

This Python package implements communications over BLE, and is meant to be used by the Home Assistant Medcom BLE integration.


## License

License: MIT

This library was written using https://github.com/vincegio/airthings-ble as the reference, which is also on the MIT license, (c) 2018 by Daniel Høyer Iversen.

